@@ -1,5 +1,5 @@
 class IMG4(object):
-    def __init__(self, file):
+    def __init__(self, file: str):
         super().__init__()
 
         self.file = file
