@@ -11,13 +11,13 @@ except ImportError:
     raise
 
 try:
-    from .utils import showProgress
+    from utils import showProgress
 except ImportError:
     raise
 
 
 class API(object):
-    def __init__(self, device: str, version: str, buildid=False, ota=False, beta=False):
+    def __init__(self, device: str, version=False, buildid=False, ota=False, beta=False):
         super().__init__()
 
         self.device = device
